@@ -44,10 +44,9 @@ def runserver(host, port):
 def sync_customers():
     """Udpate customers from CRM"""
     LOGS.logger.info("Sync customers from CRM -- START")
-    products = ["business_access", "business_plus"] #, "airfiber"]
+    products = ["business_access", "business_plus"]
     for product in products:
         customers = core.get_customers_crm(product)
-
         for customer in customers:
             print(customer)
             name = customer['ident'].lower()
@@ -62,7 +61,7 @@ def sync_customers():
                     core.update_customer(name, product_name, refnum)
             else:
                 core.create_customer(name, product_name, refnum)
-            #core.sync_customer(name, product_name, refnum)
+    core.clean_database()
     LOGS.logger.info("Sync customers from CRM -- END")
 
 
