@@ -305,7 +305,7 @@ def clean_database():
     customers_crm = []
     for product in ["business_access", "business_plus"]:
         customers = get_customers_crm(product)
-        customers_crm += [customer['ident'] for customer in customers]
+        customers_crm += [customer['ident'].lower() for customer in customers]
 
     customers_si = get_customers_si()
     customers_si = [customer['name'] for customer in customers_si]
